// Module Name: maze.cpp
// Author:      Stephen Manley (smanley@nyx.net)
//
// Description:
//
// This class is the maze object. It is comprised of two
// planes representing a floor and ceiling, a set of 
// X and Y dimensions, a rotation about it's axis, and
// a display scaling factor.
//
///////////////////////////////////////////////////////////////////////////
#ifndef MAZE
#define MAZE

#ifndef WALL
#include "wall.h"
#endif
 
class Maze
{
	public:
	
		// Constructors / Destructors
		Maze();
		~Maze();

		// Operations
		void draw();
		void drawPlane(double z);
		void drawCheckerPlane(double z);
		void generateMaze();
		void load();
		void animate(int degrees);

		// Modifiers
		void addRotation(double x, double y, double z);
		void addScale(double x, double y, double z);

		void setRotation(double x, double y, double z);
		void setScale(double x, double y, double z);
		void setAnimate(int aniFlag);
		
		void getRotation(double &x, double &y, double &z);
		void getScale(double &x, double &y, double &z);

	private:

		double xRotation;
		double yRotation;
		double zRotation;

		double xScale;
		double yScale;
		double zScale;

		int xSize;
		int ySize;
		int mazeEnabled;
		int animated;

		// Wall Constructs
		Wall* mazeWalls[1600];

		// Raw colors from file
		double* colorArray; 
};
#endif
