// Module Name: wall.cpp
// Author:      Stephen Manley (smanley@nyx.net)
//
// Description:
// 
// This class represents the wall in a maze. They have a set of
// coordinates which define it's position, a style with which
// they can draw themselves, and the ability to toggle on and
// off.
//
///////////////////////////////////////////////////////////////////////////

#include <GL/gl.h>
#include <GL/glut.h>
#include <iostream.h>
#include <fstream.h>

#ifndef WALL
#include "wall.h"
#endif

Wall::Wall()
{
}

Wall::~Wall()
{
}

Wall::Wall(	double xx1, double yy1, double zz1,
			double xx2, double yy2, double zz2,
			double xx3, double yy3, double zz3,
			double xx4, double yy4, double zz4)
{
	x1 = xx1;
	y1 = yy1;
	z1 = zz1;

	x2 = xx2;
	y2 = yy2;
	z2 = zz2;

	x3 = xx3;
	y3 = yy3;
	z3 = zz3;

	x4 = xx4;
	y4 = yy4;
	z4 = zz4;
}

void Wall::setCoords(double cx1, double cy1, double cz1,
               double cx2, double cy2, double cz2,
               double cx3, double cy3, double cz3,
               double cx4, double cy4, double cz4)
{
	x1 = cx1;
	y1 = cy1;
	z1 = cz1;

	x2 = cx2;
	y2 = cy2;
	z2 = cz2;

	x3 = cx3;
	y3 = cy3;
	z3 = cz3;

	x4 = cx4;
	y4 = cy4;
	z4 = cz4;	
}

void Wall::draw()
{
	if (!isActive)
		return;

	// Pick which tile to draw with
	if (drawType == 1)
		drawWall1(x1,y1,z1, x2,y2,z2, x3,y3,z3, z4,y4,z4);
	else if (drawType == 2)
		drawWall2(x1,y1,z1, x2,y2,z2, x3,y3,z3, z4,y4,z4);
	else
		drawWall3(x1,y1,z1, x2,y2,z2, x3,y3,z3, z4,y4,z4);
}

void Wall::setActive(int act)
{
	isActive = act;
}

// Draws a plane (heh) old blue panel
void Wall::drawWall1(	double cx1, double cy1, double cz1,
						double cx2, double cy2, double cz2,
						double cx3, double cy3, double cz3,
						double cx4, double cy4, double cz4)
{
	glColor3f(0.0, 0.0, 1.0);

    glBegin(GL_QUADS);

	glVertex3d(cx1, cy1, cz1);
	glVertex3d(cx2, cy2, cz2);
	glVertex3d(cx3, cy3, cz3);
	glVertex3d(cx4, cy4, cz4);

    glEnd();
}

// Draws two triangles to make a panel, blue and yellow
void Wall::drawWall2(	double cx1, double cy1, double cz1,
						double cx2, double cy2, double cz2,
						double cx3, double cy3, double cz3,
						double cx4, double cy4, double cz4)
{

    glColor3f(0,0,1);
    
    glBegin(GL_TRIANGLES);
	glVertex3d(cx1, cy1, cz1);
	glVertex3d(cx2, cy2, cz2);
	glVertex3d(cx3, cy3, cz3);
	glEnd();

    glColor3f(1,1,0);
    
    glBegin(GL_TRIANGLES);
	glVertex3d(cx1, cy1, cz1);
	glVertex3d(cx3, cy3, cz3);	
	glVertex3d(cx4, cy4, cz4);
	glEnd();
}

// Draws a panel with a line through the middle
void Wall::drawWall3(	double cx1, double cy1, double cz1,
						double cx2, double cy2, double cz2,
						double cx3, double cy3, double cz3,
						double cx4, double cy4, double cz4)
{
    glColor3f(1,0,0);

	glBegin(GL_QUADS);
	glVertex3d(cx1, cy1, cz1);
	glVertex3d(cx2, cy2, cz2);
	glVertex3d(cx3, cy3, cz3);
	glVertex3d(cx4, cy4, cz4);
	glEnd();

    glColor3f(1,1,1);

	glLineWidth(2.0);

	glBegin(GL_LINES);
	glVertex3d(cx1, cy1, cz1);
	glVertex3d(cx3, cy3, cz3);
	glEnd();

}

void Wall::setType(int type)
{
	drawType = type;
}
